=======
Authors
=======

The following folks have contributed to making this library possible.

* Andy Dirnberger (`@dirn <https://github.com/dirn>`_)
* Jon Banafato (`@jonafato <https://github.com/jonafato>`_)
* Leonard Bedner (`@lbedner <https://github.com/lbedner>`_)
